@@ -2,8 +2,8 @@
 //  RQuantLib function BermudanSwaption
 //
 //  Copyright (C) 2005 - 2007  Dominick Samperi
-//  Copyright (C) 2007 - 2020  Dirk Eddelbuettel
-//  Copyright (C) 2016         Terry Leitch
+//  Copyright (C) 2007 - 2024  Dirk Eddelbuettel
+//  Copyright (C) 2016 - 2023  Terry Leitch
 //
 //  This file is part of RQuantLib.
 //
@@ -45,7 +45,7 @@ void calibrateModel(const QuantLib::ext::shared_ptr<QuantLib::ShortRateModel>& m
                                                            1000, 0.05, 1.50);
 	QuantLib::Volatility diff = implied - swaptionVols(i, numCols-i-1);
 
-	Rprintf((char*) "%dx%d: model %lf, market %lf, diff %lf\n",
+	Rprintf((char*) "%.0fx%.0f: model %lf, market %lf, diff %lf\n",
             swaptionMat[i], swapLengths[numCols-i-1], implied,
             swaptionVols(i, numCols-i-1), diff);
     }
@@ -86,11 +86,11 @@ Rcpp::List bermudanFromYieldEngine(Rcpp::List rparam,
     QuantLib::DayCounter termStructureDayCounter =
         QuantLib::ActualActual(QuantLib::ActualActual::ISDA);
 
-    QuantLib::ext::shared_ptr<QuantLib::Quote> flatRate(new QuantLib::SimpleQuote(yield[0]));  // FIXME: hardcoded?
+    auto flatRate = qlext::make_shared<QuantLib::SimpleQuote>(yield[0]);  // FIXME: hardcoded?
     QuantLib::Handle<QuantLib::YieldTermStructure>
-        rhTermStructure(QuantLib::ext::shared_ptr<QuantLib::FlatForward>(new QuantLib::FlatForward(settlementDate,
-                                                                                           QuantLib::Handle<QuantLib::Quote>(flatRate),
-                                                                                           QuantLib::Actual365Fixed())));
+        rhTermStructure(qlext::make_shared<QuantLib::FlatForward>(QuantLib::FlatForward(settlementDate,
+                                                                                        QuantLib::Handle<QuantLib::Quote>(flatRate),
+                                                                                        QuantLib::Actual365Fixed())));
 
     // Get swaption vol matrix.
     //Rcpp::NumericMatrix swaptionVols(vols);
@@ -121,7 +121,7 @@ Rcpp::List bermudanFromYieldEngine(Rcpp::List rparam,
     QuantLib::DayCounter fixedLegDayCounter = QuantLib::Thirty360(QuantLib::Thirty360::European);
     QuantLib::Frequency floatingLegFrequency = QuantLib::Semiannual;
     QuantLib::Rate dummyFixedRate = 0.03;
-    QuantLib::ext::shared_ptr<QuantLib::IborIndex> indexSixMonths(new QuantLib::Euribor6M(rhTermStructure));
+    auto indexSixMonths = qlext::make_shared<QuantLib::Euribor6M>(rhTermStructure);
 
     //QuantLib::Date startDate = calendar.advance(settlementDate, 1, QuantLib::Years, floatingLegConvention);  //took out hard coded
     //QuantLib::Date maturity = calendar.advance(startDate, 5, QuantLib::Years, floatingLegConvention);         //dates
@@ -134,12 +134,12 @@ Rcpp::List bermudanFromYieldEngine(Rcpp::List rparam,
                                      floatingLegConvention,floatingLegConvention,
                                      QuantLib::DateGeneration::Forward,false);
     QuantLib::VanillaSwap::Type type = QuantLib::VanillaSwap::Payer;
-    QuantLib::ext::shared_ptr<QuantLib::VanillaSwap>
-        swap(new QuantLib::VanillaSwap(type, notional,
-                                       fixedSchedule, dummyFixedRate, fixedLegDayCounter,
-                                       floatSchedule, indexSixMonths, 0.0,
-                                       indexSixMonths->dayCounter()));
-    swap->setPricingEngine(QuantLib::ext::shared_ptr<QuantLib::PricingEngine>(new QuantLib::DiscountingSwapEngine(rhTermStructure)));
+    auto swap = qlext::make_shared<QuantLib::VanillaSwap>(type, notional,
+                                                          fixedSchedule, dummyFixedRate,
+                                                          fixedLegDayCounter,
+                                                          floatSchedule, indexSixMonths, 0.0,
+                                                          indexSixMonths->dayCounter());
+    swap->setPricingEngine(qlext::make_shared<QuantLib::DiscountingSwapEngine>(rhTermStructure));
 
     // Find the ATM or break-even rate
     QuantLib::Rate fixedATMRate = swap->fairRate();
@@ -151,12 +151,12 @@ Rcpp::List bermudanFromYieldEngine(Rcpp::List rparam,
         fixedRate = strike;
 
     // The swap underlying the Bermudan swaption.
-    QuantLib::ext::shared_ptr<QuantLib::VanillaSwap>
-        mySwap(new QuantLib::VanillaSwap(type, notional,
-                                         fixedSchedule, fixedRate, fixedLegDayCounter,
-                                         floatSchedule, indexSixMonths, 0.0,
-                                         indexSixMonths->dayCounter()));
-    swap->setPricingEngine(QuantLib::ext::shared_ptr<QuantLib::PricingEngine>(new QuantLib::DiscountingSwapEngine(rhTermStructure)));
+    auto mySwap = qlext::make_shared<QuantLib::VanillaSwap>(type, notional,
+                                                            fixedSchedule, fixedRate,
+                                                            fixedLegDayCounter,
+                                                            floatSchedule, indexSixMonths, 0.0,
+                                                            indexSixMonths->dayCounter());
+    swap->setPricingEngine(qlext::make_shared<QuantLib::DiscountingSwapEngine>(rhTermStructure));
 
     // Build swaptions that will be used to calibrate model to
     // the volatility matrix.
@@ -170,16 +170,15 @@ Rcpp::List bermudanFromYieldEngine(Rcpp::List rparam,
     // List of times that have to be included in the timegrid
     std::list<QuantLib::Time> times;
     for (i=0; i<(QuantLib::Size)numRows; i++) {
-        //QuantLib::ext::shared_ptr<QuantLib::Quote> vol(new QuantLib::SimpleQuote(swaptionVols[i][numCols-i-1]));
-        QuantLib::ext::shared_ptr<QuantLib::Quote> vol(new QuantLib::SimpleQuote(swaptionVols(i, numCols-i-1)));
-        swaptions.push_back(QuantLib::ext::shared_ptr<QuantLib::BlackCalibrationHelper>(new QuantLib::SwaptionHelper(swaptionMaturities[i],
-                                                                                                             QuantLib::Period(swapLengths[numCols-i-1], QuantLib::Years),
-                                                                                                             QuantLib::Handle<QuantLib::Quote>(vol),
-                                                                                                             indexSixMonths,
-                                                                                                             indexSixMonths->tenor(),
-                                                                                                             indexSixMonths->dayCounter(),
-                                                                                                             indexSixMonths->dayCounter(),
-                                                                                                             rhTermStructure)));
+        auto vol = qlext::make_shared<QuantLib::SimpleQuote>(swaptionVols(i, numCols-i-1));
+        swaptions.push_back(qlext::make_shared<QuantLib::SwaptionHelper>(swaptionMaturities[i],
+                                                                         QuantLib::Period(swapLengths[numCols-i-1], QuantLib::Years),
+                                                                         QuantLib::Handle<QuantLib::Quote>(vol),
+                                                                         indexSixMonths,
+                                                                         indexSixMonths->tenor(),
+                                                                         indexSixMonths->dayCounter(),
+                                                                         indexSixMonths->dayCounter(),
+                                                                         rhTermStructure));
         swaptions.back()->addTimesTo(times);
 
     }
@@ -189,22 +188,21 @@ Rcpp::List bermudanFromYieldEngine(Rcpp::List rparam,
 
     // Get Bermudan swaption exercise dates.
     std::vector<QuantLib::Date> bermudanDates;
-    const std::vector<QuantLib::ext::shared_ptr<QuantLib::CashFlow> >& leg = swap->fixedLeg();
+    const std::vector<QuantLib::ext::shared_ptr<QuantLib::CashFlow>>& leg = swap->fixedLeg();
     for (i=0; i<leg.size(); i++) {
         QuantLib::ext::shared_ptr<QuantLib::Coupon> coupon = QuantLib::ext::dynamic_pointer_cast<QuantLib::Coupon>(leg[i]);
         bermudanDates.push_back(coupon->accrualStartDate());
     }
-    QuantLib::ext::shared_ptr<QuantLib::Exercise> bermudaExercise(new QuantLib::BermudanExercise(bermudanDates));
+    auto bermudaExercise = qlext::make_shared<QuantLib::BermudanExercise>(bermudanDates);
 
     // Price based on method selected.
     if (method.compare("G2Analytic") == 0) {
-
-        QuantLib::ext::shared_ptr<QuantLib::G2> modelG2(new QuantLib::G2(rhTermStructure));
+        auto modelG2 = qlext::make_shared<QuantLib::G2>(rhTermStructure);
         Rprintf((char*)"G2/Jamshidian (analytic) calibration\n");
-        for(i = 0; i < swaptions.size(); i++)
-            swaptions[i]->setPricingEngine(QuantLib::ext::shared_ptr<QuantLib::PricingEngine>(new QuantLib::G2SwaptionEngine(modelG2, 6.0, 16)));
+        for (i = 0; i < swaptions.size(); i++)
+            swaptions[i]->setPricingEngine(qlext::make_shared<QuantLib::G2SwaptionEngine>(modelG2, 6.0, 16));
         calibrateModel(modelG2, swaptions, 0.05, swaptionMat, swapLengths, swaptionVols);
-        QuantLib::ext::shared_ptr<QuantLib::PricingEngine> engine(new QuantLib::TreeSwaptionEngine(modelG2, 50));
+        auto engine = qlext::make_shared<QuantLib::TreeSwaptionEngine>(modelG2, 50);
         QuantLib::Swaption bermudanSwaption(mySwap, bermudaExercise);
         bermudanSwaption.setPricingEngine(engine);
         return Rcpp::List::create(Rcpp::Named("a")         = modelG2->params()[0],
@@ -217,13 +215,12 @@ Rcpp::List bermudanFromYieldEngine(Rcpp::List rparam,
                                   //Rcpp::Named("params")    = params);
 
     } else if (method.compare("HWAnalytic") == 0) {
-
-        QuantLib::ext::shared_ptr<QuantLib::HullWhite> modelHW(new QuantLib::HullWhite(rhTermStructure));
+        auto modelHW = qlext::make_shared<QuantLib::HullWhite>(rhTermStructure);
         Rprintf((char*)"Hull-White (analytic) calibration\n");
         for (i=0; i<swaptions.size(); i++)
-            swaptions[i]->setPricingEngine(QuantLib::ext::shared_ptr<QuantLib::PricingEngine>(new QuantLib::JamshidianSwaptionEngine(modelHW)));
+            swaptions[i]->setPricingEngine(qlext::make_shared<QuantLib::JamshidianSwaptionEngine>(modelHW));
         calibrateModel(modelHW, swaptions, 0.05, swaptionMat, swapLengths, swaptionVols);
-        QuantLib::ext::shared_ptr<QuantLib::PricingEngine> engine(new QuantLib::TreeSwaptionEngine(modelHW, 50));
+        auto engine = qlext::make_shared<QuantLib::TreeSwaptionEngine>(modelHW, 50);
         QuantLib::Swaption bermudanSwaption(mySwap, bermudaExercise);
         bermudanSwaption.setPricingEngine(engine);
         return Rcpp::List::create(Rcpp::Named("a") = modelHW->params()[0],
@@ -233,13 +230,13 @@ Rcpp::List bermudanFromYieldEngine(Rcpp::List rparam,
         //Rcpp::Named("params") = params);
 
     } else if (method.compare("HWTree") == 0) {
-        QuantLib::ext::shared_ptr<QuantLib::HullWhite> modelHW2(new QuantLib::HullWhite(rhTermStructure));
+        auto modelHW2 = qlext::make_shared<QuantLib::HullWhite>(rhTermStructure);
         Rprintf((char*)"Hull-White (tree) calibration\n");
         for (i=0; i<swaptions.size(); i++)
-            swaptions[i]->setPricingEngine(QuantLib::ext::shared_ptr<QuantLib::PricingEngine>(new QuantLib::TreeSwaptionEngine(modelHW2,grid)));
+            swaptions[i]->setPricingEngine(qlext::make_shared<QuantLib::TreeSwaptionEngine>(modelHW2,grid));
 
         calibrateModel(modelHW2, swaptions, 0.05, swaptionMat, swapLengths, swaptionVols);
-        QuantLib::ext::shared_ptr<QuantLib::PricingEngine> engine(new QuantLib::TreeSwaptionEngine(modelHW2, 50));
+        auto engine = qlext::make_shared<QuantLib::TreeSwaptionEngine>(modelHW2, 50);
         QuantLib::Swaption bermudanSwaption(mySwap, bermudaExercise);
         bermudanSwaption.setPricingEngine(engine);
         return Rcpp::List::create(Rcpp::Named("a") = modelHW2->params()[0],
@@ -249,13 +246,13 @@ Rcpp::List bermudanFromYieldEngine(Rcpp::List rparam,
         //Rcpp::Named("params") = params);
 
     } else if (method.compare("BKTree") == 0) {
-        QuantLib::ext::shared_ptr<QuantLib::BlackKarasinski> modelBK(new QuantLib::BlackKarasinski(rhTermStructure));
+        auto modelBK = qlext::make_shared<QuantLib::BlackKarasinski>(rhTermStructure);
         Rprintf((char*)"Black-Karasinski (tree) calibration\n");
         for (i=0; i<swaptions.size(); i++)
-            swaptions[i]->setPricingEngine(QuantLib::ext::shared_ptr<QuantLib::PricingEngine>(new QuantLib::TreeSwaptionEngine(modelBK,grid)));
+            swaptions[i]->setPricingEngine(qlext::make_shared<QuantLib::TreeSwaptionEngine>(modelBK,grid));
         calibrateModel(modelBK, swaptions, 0.05, swaptionMat, swapLengths, swaptionVols);
 
-        QuantLib::ext::shared_ptr<QuantLib::PricingEngine> engine(new QuantLib::TreeSwaptionEngine(modelBK, 50));
+        auto engine = qlext::make_shared<QuantLib::TreeSwaptionEngine>(modelBK, 50);
         QuantLib::Swaption bermudanSwaption(mySwap, bermudaExercise);
         bermudanSwaption.setPricingEngine(engine);
         return Rcpp::List::create(Rcpp::Named("a") = modelBK->params()[0],
@@ -339,7 +336,7 @@ Rcpp::List bermudanWithRebuiltCurveEngine(Rcpp::List rparam,
     QuantLib::DayCounter fixedLegDayCounter = QuantLib::Thirty360(QuantLib::Thirty360::European);
     QuantLib::Frequency floatingLegFrequency = QuantLib::Semiannual;
     QuantLib::Rate dummyFixedRate = 0.03;
-    QuantLib::ext::shared_ptr<QuantLib::IborIndex> indexSixMonths(new QuantLib::Euribor6M(rhTermStructure));
+    auto indexSixMonths = qlext::make_shared<QuantLib::Euribor6M>(rhTermStructure);
 
     //QuantLib::Date startDate = calendar.advance(settlementDate, 1, QuantLib::Years, floatingLegConvention);  //took out hard coded
     //QuantLib::Date maturity = calendar.advance(startDate, 5, QuantLib::Years, floatingLegConvention);         //dates
@@ -360,12 +357,12 @@ Rcpp::List bermudanWithRebuiltCurveEngine(Rcpp::List rparam,
     }
 
 
-    QuantLib::ext::shared_ptr<QuantLib::VanillaSwap>
-        swap(new QuantLib::VanillaSwap(type, notional,
-                                       fixedSchedule, dummyFixedRate, fixedLegDayCounter,
-                                       floatSchedule, indexSixMonths, 0.0,
-                                       indexSixMonths->dayCounter()));
-    swap->setPricingEngine(QuantLib::ext::shared_ptr<QuantLib::PricingEngine>(new QuantLib::DiscountingSwapEngine(rhTermStructure)));
+    auto swap = qlext::make_shared<QuantLib::VanillaSwap>(type, notional,
+                                                          fixedSchedule, dummyFixedRate,
+                                                          fixedLegDayCounter,
+                                                          floatSchedule, indexSixMonths, 0.0,
+                                                          indexSixMonths->dayCounter());
+    swap->setPricingEngine(qlext::make_shared<QuantLib::DiscountingSwapEngine>(rhTermStructure));
 
     // Find the ATM or break-even rate
     QuantLib::Rate fixedATMRate = swap->fairRate();
@@ -377,12 +374,12 @@ Rcpp::List bermudanWithRebuiltCurveEngine(Rcpp::List rparam,
         fixedRate = strike;
 
     // The swap underlying the Bermudan swaption.
-    QuantLib::ext::shared_ptr<QuantLib::VanillaSwap>
-        mySwap(new QuantLib::VanillaSwap(type, notional,
-                                         fixedSchedule, fixedRate, fixedLegDayCounter,
-                                         floatSchedule, indexSixMonths, 0.0,
-                                         indexSixMonths->dayCounter()));
-    swap->setPricingEngine(QuantLib::ext::shared_ptr<QuantLib::PricingEngine>(new QuantLib::DiscountingSwapEngine(rhTermStructure)));
+    auto mySwap = qlext::make_shared<QuantLib::VanillaSwap>(type, notional,
+                                                            fixedSchedule, fixedRate,
+                                                            fixedLegDayCounter,
+                                                            floatSchedule, indexSixMonths, 0.0,
+                                                            indexSixMonths->dayCounter());
+    swap->setPricingEngine(qlext::make_shared<QuantLib::DiscountingSwapEngine>(rhTermStructure));
 
     // Build swaptions that will be used to calibrate model to
     // the volatility matrix.
@@ -396,17 +393,15 @@ Rcpp::List bermudanWithRebuiltCurveEngine(Rcpp::List rparam,
     // List of times that have to be included in the timegrid
     std::list<QuantLib::Time> times;
     for (i=0; i<(QuantLib::Size)numRows; i++) {
-
-        //QuantLib::ext::shared_ptr<QuantLib::Quote> vol(new QuantLib::SimpleQuote(swaptionVols[i][numCols-i-1]));
-        QuantLib::ext::shared_ptr<QuantLib::Quote> vol(new QuantLib::SimpleQuote(swaptionVols(i, numCols-i-1)));
-        swaptions.push_back(QuantLib::ext::shared_ptr<QuantLib::BlackCalibrationHelper>(new QuantLib::SwaptionHelper(swaptionMaturities[i],
-                                                                                                             QuantLib::Period(swapLengths[numCols-i-1], QuantLib::Years),
-                                                                                                             QuantLib::Handle<QuantLib::Quote>(vol),
-                                                                                                             indexSixMonths,
-                                                                                                             indexSixMonths->tenor(),
-                                                                                                             indexSixMonths->dayCounter(),
-                                                                                                             indexSixMonths->dayCounter(),
-                                                                                                             rhTermStructure)));
+        auto vol = qlext::make_shared<QuantLib::SimpleQuote>(swaptionVols(i, numCols-i-1));
+        swaptions.push_back(qlext::make_shared<QuantLib::SwaptionHelper>(swaptionMaturities[i],
+                                                                         QuantLib::Period(swapLengths[numCols-i-1], QuantLib::Years),
+                                                                         QuantLib::Handle<QuantLib::Quote>(vol),
+                                                                         indexSixMonths,
+                                                                         indexSixMonths->tenor(),
+                                                                         indexSixMonths->dayCounter(),
+                                                                         indexSixMonths->dayCounter(),
+                                                                         rhTermStructure));
         swaptions.back()->addTimesTo(times);
     }
 
@@ -418,56 +413,54 @@ Rcpp::List bermudanWithRebuiltCurveEngine(Rcpp::List rparam,
     std::vector<QuantLib::Date> bermudanDates;
     const std::vector<QuantLib::ext::shared_ptr<QuantLib::CashFlow> >& leg = swap->fixedLeg();
     for (i=0; i<leg.size(); i++) {
-        QuantLib::ext::shared_ptr<QuantLib::Coupon> coupon = QuantLib::ext::dynamic_pointer_cast<QuantLib::Coupon>(leg[i]);
+        auto coupon = QuantLib::ext::dynamic_pointer_cast<QuantLib::Coupon>(leg[i]);
         bermudanDates.push_back(coupon->accrualStartDate());
     }
 
-    QuantLib::ext::shared_ptr<QuantLib::Exercise> bermudaExercise(new QuantLib::BermudanExercise(bermudanDates));
+    auto bermudaExercise = qlext::make_shared<QuantLib::BermudanExercise>(bermudanDates);
 
     // Price based on method selected.
     if (method.compare("G2Analytic") == 0) {
-
-        QuantLib::ext::shared_ptr<QuantLib::G2> modelG2(new QuantLib::G2(rhTermStructure));
+        auto modelG2 = qlext::make_shared<QuantLib::G2>(rhTermStructure);
         Rprintf((char*)"G2/Jamshidian (analytic) calibration\n");
         for(i = 0; i < swaptions.size(); i++)
-          swaptions[i]->setPricingEngine(QuantLib::ext::shared_ptr<QuantLib::PricingEngine>(new QuantLib::G2SwaptionEngine(modelG2, 6.0, 16)));
+          swaptions[i]->setPricingEngine(qlext::make_shared<QuantLib::G2SwaptionEngine>(modelG2, 6.0, 16));
         calibrateModel(modelG2, swaptions, 0.05, swaptionMat, swapLengths, swaptionVols);
-        QuantLib::ext::shared_ptr<QuantLib::PricingEngine> engine(new QuantLib::TreeSwaptionEngine(modelG2, 50));
+        auto engine = qlext::make_shared<QuantLib::TreeSwaptionEngine>(modelG2, 50);
         QuantLib::Swaption bermudanSwaption(mySwap, bermudaExercise);
         bermudanSwaption.setPricingEngine(engine);
         return Rcpp::List::create(Rcpp::Named("a")         = modelG2->params()[0],
                                   Rcpp::Named("sigma")     = modelG2->params()[1],
-                                                                              Rcpp::Named("b")         = modelG2->params()[2],
-                                                                                                                          Rcpp::Named("eta")       = modelG2->params()[3],
-                                                                                                                                                                      Rcpp::Named("rho")       = modelG2->params()[4],
-                                                                                                                                                                                                                  Rcpp::Named("price")     = bermudanSwaption.NPV(),
-                                                                                                                                                                                                                  Rcpp::Named("ATMStrike") = fixedATMRate);
+                                  Rcpp::Named("b")         = modelG2->params()[2],
+                                  Rcpp::Named("eta")       = modelG2->params()[3],
+                                  Rcpp::Named("rho")       = modelG2->params()[4],
+                                  Rcpp::Named("price")     = bermudanSwaption.NPV(),
+                                  Rcpp::Named("ATMStrike") = fixedATMRate);
         //Rcpp::Named("params")    = params);
 
     } else if (method.compare("HWAnalytic") == 0) {
-
-        QuantLib::ext::shared_ptr<QuantLib::HullWhite> modelHW(new QuantLib::HullWhite(rhTermStructure));
+        auto modelHW = qlext::make_shared<QuantLib::HullWhite>(rhTermStructure);
         Rprintf((char*)"Hull-White (analytic) calibration\n");
         for (i=0; i<swaptions.size(); i++)
-            swaptions[i]->setPricingEngine(QuantLib::ext::shared_ptr<QuantLib::PricingEngine>(new QuantLib::JamshidianSwaptionEngine(modelHW)));
+            swaptions[i]->setPricingEngine(qlext::make_shared<QuantLib::JamshidianSwaptionEngine>(modelHW));
         calibrateModel(modelHW, swaptions, 0.05, swaptionMat, swapLengths, swaptionVols);
-        QuantLib::ext::shared_ptr<QuantLib::PricingEngine> engine(new QuantLib::TreeSwaptionEngine(modelHW, 50));
+        auto engine = qlext::make_shared<QuantLib::TreeSwaptionEngine>(modelHW, 50);
         QuantLib::Swaption bermudanSwaption(mySwap, bermudaExercise);
         bermudanSwaption.setPricingEngine(engine);
         return Rcpp::List::create(Rcpp::Named("a") = modelHW->params()[0],
                                   Rcpp::Named("sigma") = modelHW->params()[1],
-                                                                          Rcpp::Named("price") = bermudanSwaption.NPV(),
-                                                                          Rcpp::Named("ATMStrike") = fixedATMRate);
+                                  Rcpp::Named("price") = bermudanSwaption.NPV(),
+                                  Rcpp::Named("ATMStrike") = fixedATMRate);
         //Rcpp::Named("params") = params);
 
     } else if (method.compare("HWTree") == 0) {
-        QuantLib::ext::shared_ptr<QuantLib::HullWhite> modelHW2(new QuantLib::HullWhite(rhTermStructure));
+        auto modelHW2 = qlext::make_shared<QuantLib::HullWhite>(rhTermStructure);
         Rprintf((char*)"Hull-White (tree) calibration\n");
         for (i=0; i<swaptions.size(); i++)
-            swaptions[i]->setPricingEngine(QuantLib::ext::shared_ptr<QuantLib::PricingEngine>(new QuantLib::TreeSwaptionEngine(modelHW2,grid)));
+            swaptions[i]->setPricingEngine(qlext::make_shared<QuantLib::TreeSwaptionEngine>(modelHW2,grid));
 
         calibrateModel(modelHW2, swaptions, 0.05, swaptionMat, swapLengths, swaptionVols);
-        QuantLib::ext::shared_ptr<QuantLib::PricingEngine> engine(new QuantLib::TreeSwaptionEngine(modelHW2, 50));
+        auto engine = qlext::make_shared<QuantLib::TreeSwaptionEngine>(modelHW2, 50);
         QuantLib::Swaption bermudanSwaption(mySwap, bermudaExercise);
         bermudanSwaption.setPricingEngine(engine);
         return Rcpp::List::create(Rcpp::Named("a") = modelHW2->params()[0],
@@ -477,19 +470,19 @@ Rcpp::List bermudanWithRebuiltCurveEngine(Rcpp::List rparam,
         //Rcpp::Named("params") = params);
 
     } else if (method.compare("BKTree") == 0) {
-        QuantLib::ext::shared_ptr<QuantLib::BlackKarasinski> modelBK(new QuantLib::BlackKarasinski(rhTermStructure));
+        auto modelBK = qlext::make_shared<QuantLib::BlackKarasinski>(rhTermStructure);
         Rprintf((char*)"Black-Karasinski (tree) calibration\n");
         for (i=0; i<swaptions.size(); i++)
-            swaptions[i]->setPricingEngine(QuantLib::ext::shared_ptr<QuantLib::PricingEngine>(new QuantLib::TreeSwaptionEngine(modelBK,grid)));
+            swaptions[i]->setPricingEngine(qlext::make_shared<QuantLib::TreeSwaptionEngine>(modelBK,grid));
         calibrateModel(modelBK, swaptions, 0.05, swaptionMat, swapLengths, swaptionVols);
 
-        QuantLib::ext::shared_ptr<QuantLib::PricingEngine> engine(new QuantLib::TreeSwaptionEngine(modelBK, 50));
+        auto engine = qlext::make_shared<QuantLib::TreeSwaptionEngine>(modelBK, 50);
         QuantLib::Swaption bermudanSwaption(mySwap, bermudaExercise);
         bermudanSwaption.setPricingEngine(engine);
         return Rcpp::List::create(Rcpp::Named("a") = modelBK->params()[0],
                                   Rcpp::Named("sigma") = modelBK->params()[1],
-                                                                          Rcpp::Named("price") = bermudanSwaption.NPV(),
-                                                                          Rcpp::Named("ATMStrike") = fixedATMRate);
+                                  Rcpp::Named("price") = bermudanSwaption.NPV(),
+                                  Rcpp::Named("ATMStrike") = fixedATMRate);
         //Rcpp::Named("params") = params);
 
     } else {
