@@ -2,7 +2,7 @@
 //  RQuantLib -- R interface to the QuantLib libraries
 //
 //  Copyright (C) 2009 - 2012  Dirk Eddelbuettel and Khanh Nguyen
-//  Copyright (C) 2013 - 2021  Dirk Eddelbuettel
+//  Copyright (C) 2013 - 2024  Dirk Eddelbuettel
 //
 //  RQuantLib is free software: you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -57,8 +57,12 @@ double zeroyield(double price, QuantLib::Date maturity, QuantLib::Date settle, i
     //double EMR = Rcpp::as<double>(rparam["EMR");
 
     QuantLib::ZeroCouponBond bond(1, calendar, 100, maturity, QuantLib::Unadjusted, 100.0, settle);
-
+#if QL_HEX_VERSION >= 0x013400c0
+    QuantLib::Bond::Price bondprice{price, QuantLib::Bond::Price::Clean};
+    return bond.yield(bondprice, dayCounter, QuantLib::Compounded, freq);
+#else
     return bond.yield(price, dayCounter, QuantLib::Compounded, freq);
+#endif
 }
 
 Rcpp::DataFrame zbtyield(std::vector<QuantLib::Date> MatDates,
@@ -70,11 +74,11 @@ Rcpp::DataFrame zbtyield(std::vector<QuantLib::Date> MatDates,
     //setting up the bonds
     const QuantLib::Size numberOfBonds = MatDates.size();
 
-    std::vector<QuantLib::ext::shared_ptr<QuantLib::RateHelper> > instruments;
+    std::vector<qlext::shared_ptr<QuantLib::RateHelper> > instruments;
 
-    std::vector< QuantLib::ext::shared_ptr<QuantLib::SimpleQuote> > quote;
+    std::vector<qlext::shared_ptr<QuantLib::SimpleQuote> > quote;
     for (QuantLib::Size i=0; i<numberOfBonds; i++) {
-        QuantLib::ext::shared_ptr<QuantLib::SimpleQuote> cp(new QuantLib::SimpleQuote(cleanPrice[i]));
+        auto cp = qlext::make_shared<QuantLib::SimpleQuote>(cleanPrice[i]);
         quote.push_back(cp);
     }
 
@@ -102,10 +106,10 @@ Rcpp::DataFrame zbtyield(std::vector<QuantLib::Date> MatDates,
         QuantLib::Schedule schedule(SettleDates[j], MatDates[j],p, calendar,
                                     QuantLib::Unadjusted, QuantLib::Unadjusted,
                                     QuantLib::DateGeneration::Backward, emr);
-        QuantLib::ext::shared_ptr<QuantLib::FixedRateBondHelper>
-            helper(new QuantLib::FixedRateBondHelper(quoteHandle[j], 1, faceAmount, schedule,
-                                                     std::vector<QuantLib::Rate>(1,bondparam(j,0)),
-                                                     dayCounter, QuantLib::Unadjusted, 100, SettleDates[j]));
+        typedef QuantLib::FixedRateBondHelper qlFRBH;
+        auto helper = qlext::make_shared<qlFRBH>(quoteHandle[j], 1, faceAmount, schedule,
+                                                 std::vector<QuantLib::Rate>(1,bondparam(j,0)),
+                                                 dayCounter, QuantLib::Unadjusted, 100, SettleDates[j]);
         instruments.push_back(helper);
     }
 
@@ -127,9 +131,8 @@ Rcpp::DataFrame zbtyield(std::vector<QuantLib::Date> MatDates,
       curve = ts3;
     */
 
-    QuantLib::ext::shared_ptr<QuantLib::YieldTermStructure>
-        curve(new QuantLib::PiecewiseYieldCurve<QuantLib::ZeroYield,
-                                                QuantLib::Cubic>(1, calendar, instruments, dayCounter));
+    typedef QuantLib::PiecewiseYieldCurve<QuantLib::ZeroYield, QuantLib::Cubic> qlPYCZYC;
+    auto curve = qlext::make_shared<qlPYCZYC>(1, calendar, instruments, dayCounter);
     int numCol = 2;
     std::vector<std::string> colNames(numCol);
     colNames[0] = "date";
